@@ -79,7 +79,7 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	 "or a combination of these), %2 are the copyright holders").arg("2002-2025").arg("Liviu Lalescu, Volker Dirr");
 	about+=QString("<br /><br />");
 	about+=tr("Version: %1 (%2 %3).", "%1 is the current FET version, %2 is the current release month, %3 is the current release year").arg(FET_VERSION)
-	 .arg(QCoreApplication::translate("MonthsNames", "September")).arg("2025");
+	 .arg(QCoreApplication::translate("MonthsNames", "October")).arg("2025");
 	about+=QString("<br /><br />");
 	about+=tr("Licensed under the GNU Affero General Public License version 3 or later.");
 	about+=QString("<br /><br />");
@@ -1395,7 +1395,7 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Michael Chourdakis");
 	thanksTo+=QString("<br />");
-	thanksTo+=QString("Thai Chi Phuong");
+	thanksTo+=QString("Thái Chí Phương");
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("gt");
 	thanksTo+=QString("<br />");
@@ -1517,6 +1517,8 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("alege");
 	thanksTo+=QString("<br />");
+	thanksTo+=QString("k3nt0n");
+	thanksTo+=QString("<br />");
 	
 	thanksToTextBrowser->setHtml(thanksTo);
 }
